@@ -92,7 +92,10 @@ from petisco.event.shared.domain.event_subscriber import EventSubscriber
 from petisco.webhooks.webhook.domain.secret import SecretIsNotHexError, Secret
 from petisco.webhooks.webhook.domain.signature_algorithm import SignatureAlgorithm
 from petisco.webhooks.webhook.domain.webhook import Webhook
+from petisco.webhooks.webhook.domain.webhook_sender_failed import WebhookSenderFailed
+from petisco.webhooks.webhook.domain.webhook_result_id import WebhookResultId
 from petisco.webhooks.webhook.domain.webhook_id import WebhookId
+from petisco.webhooks.webhook.domain.webhook_result import WebhookResult
 from petisco.webhooks.webhook.domain.webhook_sender import WebhookSender
 
 
@@ -163,6 +166,9 @@ classes = [
     "Webhook",
     "WebhookSender",
     "WebhookId",
+    "WebhookResult",
+    "WebhookResultId",
+    "WebhookSenderFailed",
     "IEventChaos",
     "SecretIsNotHexError",
     "NotHasSpecificLengthValueObjectError",
@@ -170,6 +176,7 @@ classes = [
     "SignatureAlgorithm",
 ]
 
+
 # Controllers & Use Cases
 from petisco.modules.environment.application.environment import environment
 from petisco.modules.environment.application.environment_provider import (
